@@ -157,13 +157,14 @@ def _store_on_output(*args, _store_on_ouput_args, **kwargs):
         func,
         sig,
         store,
+        store_multi_values,
         save_name_param,
         empty_name_callback,
         auto_namer,
         output_trans,
     ) = _store_on_ouput_args
     arguments = sig.kwargs_from_args_and_kwargs(args, kwargs, apply_defaults=True)
-    save_name = arguments.pop(save_name_param)
+    save_name = arguments.pop(save_name_param, None)
     if not save_name and empty_name_callback:
         assert callable(
             empty_name_callback
@@ -171,10 +172,22 @@ def _store_on_output(*args, _store_on_ouput_args, **kwargs):
         empty_name_callback()
     args, kwargs = sig.args_and_kwargs_from_kwargs(arguments)
     output = func(*args, **kwargs)
-    if not save_name and auto_namer:
-        save_name = call_forgivingly(auto_namer, arguments=arguments, output=output)
-    if save_name:
-        store[save_name] = output
+    if store_multi_values:
+        if not isinstance(output, Iterable) or save_name or not auto_namer:
+            raise TypeError(
+                f'When store_multi_values is True, output must be Iterable, save_name \
+must be None and auto_namer must be defined. Got: {output}, {save_name}, {auto_namer}'
+            )
+        for output_item in output:
+            save_name = call_forgivingly(
+                auto_namer, arguments=arguments, output=output_item
+            )
+            store[save_name] = output_item
+    else:
+        if not save_name and auto_namer:
+            save_name = call_forgivingly(auto_namer, arguments=arguments, output=output)
+        if save_name:
+            store[save_name] = output
     if not output_trans:
         return output
     else:
@@ -190,6 +203,7 @@ def store_on_output(
     func=None,
     *,
     store=None,
+    store_multi_values=False,
     save_name_param='save_name',
     add_store_to_func_attr='output_store',
     empty_name_callback: Callable[[], Any] = None,
@@ -207,9 +221,13 @@ def store_on_output(
 
     :param func: Function that we're wrapping
     :param store: Mapping (e.g. dict) where we'd like the output to be stored in
+    :param store_multi_values: If True, store the items of an Iterable output one by 
+        one. The output needs to be an Iterable, ``save_name_param`` needs to be set to 
+        None, and the ``auto_namer`` needs to be set.
     :param save_name_param: Name of the extra param that will be added to the
         function's interface, where the user will be able to specify the key where
-        they want to save the output.
+        they want to save the output. If None, the ``auto_namer`` needs to be set to 
+        define the key.
     :param add_store_to_func_attr: If not None, the wrapped function will have an
         attribute of that name where the store will be stored
     :param empty_name_callback: If not None, will be called if the user doesn't specify
@@ -278,10 +296,37 @@ def store_on_output(
     >>> my_store
     {'all': 'mine', 'test': 5, '7_2': 9}
 
+    An example with no ``save_name_param``:
+
+    >>> my_store = {'all': 'mine'}
+    >>> @store_on_output(
+    ...     store=my_store,
+    ...     save_name_param=None,
+    ...     add_store_to_func_attr=None,
+    ...     auto_namer=lambda *, arguments: '_'.join(map(str, arguments.values()))
+    ... )
+    ... def bar(a, b: int = 2):
+    ...     return a + b
+    >>> bar(7)
+    9
+    >>> my_store
+    {'all': 'mine', '7_2': 9}
+
+    >>> my_store = {'all': 'mine'}
+    >>> @store_on_output(
+    ...     store=my_store,
+    ...     store_multi_values=True,
+    ...     save_name_param=None,
+    ...     add_store_to_func_attr=None,
+    ...     auto_namer=lambda *, arguments, output: f"{'_'.join(map(str, arguments.values()))}_{output}"
+    ... )
+    ... def bar(a, b: int = 2):
+    ...     return list(range(a + b))
+    >>> bar(7)
+    [0, 1, 2, 3, 4, 5, 6, 7, 8]
+    >>> my_store
+    {'all': 'mine', '7_2_0': 0, '7_2_1': 1, '7_2_2': 2, '7_2_3': 3, '7_2_4': 4, '7_2_5': 5, '7_2_6': 6, '7_2_7': 7, '7_2_8': 8}
     """
-    save_name_param_obj = Parameter(
-        name=save_name_param, kind=Parameter.KEYWORD_ONLY, default='', annotation=str,
-    )
     _validate_function_keyword_only_params(
         auto_namer, ['output', 'arguments'], obj_name='auto_namer'
     )
@@ -292,7 +337,20 @@ def store_on_output(
         assert callable(output_trans) and set(Sig(output_trans).names).issubset(
             ['save_name', 'output', 'arguments']
         )
-    sig = Sig(func) + [save_name_param_obj]
+    sig = Sig(func)
+    if save_name_param:
+        save_name_param_obj = Parameter(
+            name=save_name_param,
+            kind=Parameter.KEYWORD_ONLY,
+            default='',
+            annotation=str,
+        )
+        sig = sig + [save_name_param_obj]
+    elif not auto_namer:
+        raise ValueError(
+            'There is no way to determine the key under which to store the output. \
+                Set a value for the `save_name_param` or `auto_namer` parameters.'
+        )
 
     if store is None:
         store = dict()
@@ -303,6 +361,7 @@ def store_on_output(
             func,
             sig,
             store,
+            store_multi_values,
             save_name_param,
             empty_name_callback,
             auto_namer,
@@ -333,6 +392,7 @@ def prepare_for_crude_dispatch(
     include_stores_attribute: bool = False,
     output_store: Optional[Union[Mapping, str]] = None,
     # the arguments below only apply if output_store is given
+    store_multi_values: bool = False,
     save_name_param: str = 'save_name',
     empty_name_callback: Callable[[], Any] = None,
     auto_namer: Callable[..., str] = None,
@@ -575,6 +635,7 @@ def prepare_for_crude_dispatch(
         wrapped_f = store_on_output(
             wrapped_f,
             store=output_store,
+            store_multi_values=store_multi_values,
             save_name_param=save_name_param,
             add_store_to_func_attr='output_store' if include_stores_attribute else None,
             empty_name_callback=empty_name_callback,
@@ -822,7 +883,7 @@ class Crudifier(_Crudifier):
 
     For example, say we had a mini-language where this
 
-    >>> configs = {
+    >>> config = {
     ...     foo: {
     ...         'preprocesses': Crudify('x y'),
     ...         'whatevs': 42
@@ -833,7 +894,7 @@ class Crudifier(_Crudifier):
     ... }
 
     should be preprocessed in such a way that adds a ``'func'`` key to each item of
-    ``configs`` which contains a transformed function if a ```preprocess`` function
+    ``config`` which contains a transformed function if a ```preprocess`` function
     or list of functions is specified, or the original function itself otherwise.
     The following would implement this:
 
@@ -845,8 +906,8 @@ class Crudifier(_Crudifier):
     ...         v = [v]
     ...     return v
     ...
-    >>> def prepare(configs):
-    ...     for func, specs in configs.items():
+    >>> def prepare(config):
+    ...     for func, specs in config.items():
     ...         if (processes := specs.get('preprocesses', None)) is not None:
     ...             preprocess = Pipe(*_ensure_iterable(processes))
     ...             _func = preprocess(func)
@@ -855,7 +916,7 @@ class Crudifier(_Crudifier):
     ...         specs = dict(specs, func=_func)
     ...         yield func, specs
 
-    >>> prepared_configs = dict(prepare(configs))
+    >>> prepared_configs = dict(prepare(config))
 
     Now get the ``func`` value under ``foo``, and see that it has been crudified:
 
